Index: runtime/vm/object.cc |
diff --git a/runtime/vm/object.cc b/runtime/vm/object.cc |
index 428dfa34b299bd70cb87a437ba5eca91c0c33fa3..ac586d969d51a2109635fb419c67c781803cafd7 100644 |
--- a/runtime/vm/object.cc |
+++ b/runtime/vm/object.cc |
@@ -11008,8 +11008,8 @@ bool LibraryPrefix::LoadLibrary() const { |
Exceptions::PropagateError(Error::Cast(obj)); |
} |
} else { |
- // Another load request is in flight. |
- ASSERT(deferred_lib.LoadRequested()); |
+ // Another load request is in flight or previously failed. |
+ ASSERT(deferred_lib.LoadRequested() || deferred_lib.LoadFailed()); |
} |
return false; // Load request not yet completed. |
} |